# v0.2

- Fix [issue #1](https://github.com/neylsoncrepalde/deflatebr/issues/1).
- `deflate()` works for larger datasets and for situations when you have several observations with the same `nominal_dates`.